#[repr(u8)]pub enum ShadowInputType {
Shadow = 1,
NoShadow = 2,
ShadowObscured = 3,
}Expand description
Shadow enum for BlockInput
Shadow is area inside block input/arg/param or whatever you wanted to call it. It’s consisting of:
- raw input field where you just type stuff in and optionally can put a reporter in
- menu that you can choose but cannot put a reporter in
- menu that you can chose and optionally can put a reporter in
- or others I might not catch while developing this
This documentation might not be completed or is completed, idk. Scratch wiki didn’t tell anything about this.
Variants
Shadow = 1
There is a shadow
NoShadow = 2
There is no shadow
ShadowObscured = 3
There is a shadow but obscured by the input. The shadow is obscured when reporter is inserted.