pub struct Comment {
pub block_id: Option<Uid>,
pub x: Option<Number>,
pub y: Option<Number>,
pub width: Number,
pub height: Number,
pub minimized: bool,
pub text: Text,
}Expand description
Adjustable textboxes that can be attached to crate::block::Blocks, or left floating
Fields
block_id: Option<Uid>The ID of the block the comment is attached to.
x: Option<Number>The x-coordinate of the comment in the code area.
y: Option<Number>The y-coordinate of the comment in the code area.
width: NumberThe width.
height: NumberThe height.
minimized: boolTrue if the comment is collapsed and false otherwise.
text: TextThe text.