RotationStyle

Enum RotationStyle 

pub enum RotationStyle {
    AllAround,
    LeftRight,
    DontRotate,
}
A Sprite’s rotation style controls which directions a sprite can face in. These directions are all in accordance with the analogous rotation system used by Scratch. Depending on the rotation style of a sprite, the sprite may appear to be facing a different way than the direction it has been set to.

Variants



AllAround

Visually points the sprite in the direction it is facing. However, this will make the sprite appear upside-down if it is facing left.



LeftRight

Flips the sprite right or left. If the sprite’s direction is between 0° and 180°, the costume will not appear rotated. If the sprite’s direction is between 0° and -180°, the costume will be mirrored around the y axis.



DontRotate

Don’t rotate

Note: The sprite’s visual direction will not change, but the direction it moves with the Move () Steps block can still be modified.