pub enum VideoState {
On,
Off,
OnFlipped,
}Expand description
Determines if video is visible on the stage and if it is flipped. Has no effect if the project does not use an extension with video input.
Variants