pub struct Target {
pub name: Text,
pub variables: StringHashMap<Variable>,
pub lists: StringHashMap<List>,
pub broadcasts: StringHashMap<Broadcast>,
pub blocks: StringHashMap<Block>,
pub comments: StringHashMap<Comment>,
pub current_costume: Int,
pub costumes: Vec<Costume>,
pub sounds: Vec<Sound>,
pub layer_order: Int,
pub volume: Number,
}Expand description
A target is the stage or a sprite.
Fields
name: TextThe name of the sprite. Always “Stage” for the stage. If not provided, the target will not be loaded.
variables: StringHashMap<Variable>An object associating IDs with arrays representing variables.
The first element of the array is the variable name,
the second is the value and the third is true if the variable is a cloud variable,
or otherwise not present.
lists: StringHashMap<List>An object associating IDs with arrays representing lists. The first element of the array is the list name and the second is the list as an array.
broadcasts: StringHashMap<Broadcast>An object associating IDs with broadcast names. Normally only present in the stage.
blocks: StringHashMap<Block>An object associating IDs with blocks.
comments: StringHashMap<Comment>An object associating IDs with comments.
current_costume: IntThe costume number.
costumes: Vec<Costume>An array of costumes.
sounds: Vec<Sound>An array of sounds.
layer_order: IntThe layer number.
volume: NumberThe volume