Target

Struct Target 

pub struct Target {
    pub name: Text,
    pub variables: StringHashMap<Variable>,
    pub lists: StringHashMap<List>,
    pub broadcasts: StringHashMap<Broadcast>,
    pub blocks: StringHashMap<Block>,
    pub comments: StringHashMap<Comment>,
    pub current_costume: Int,
    pub costumes: Vec<Costume>,
    pub sounds: Vec<Sound>,
    pub layer_order: Int,
    pub volume: Number,
}
A target is the stage or a sprite.

Fields

name: Text

The name of the sprite. Always “Stage” for the stage. If not provided, the target will not be loaded.

variables: StringHashMap<Variable>

An object associating IDs with arrays representing variables. The first element of the array is the variable name, the second is the value and the third is true if the variable is a cloud variable, or otherwise not present.

lists: StringHashMap<List>

An object associating IDs with arrays representing lists. The first element of the array is the list name and the second is the list as an array.

broadcasts: StringHashMap<Broadcast>

An object associating IDs with broadcast names. Normally only present in the stage.

blocks: StringHashMap<Block>

An object associating IDs with blocks.

comments: StringHashMap<Comment>

An object associating IDs with comments.

current_costume: Int

The costume number.

costumes: Vec<Costume>

An array of costumes.

sounds: Vec<Sound>

An array of sounds.

layer_order: Int

The layer number.

volume: Number

The volume